# tweety
Twitter's API is annoying to work with, and has lots of limitations — luckily their frontend (JavaScript) has it's own API, which I reverse–engineered. No API rate limits. No restrictions.

## Documentation:
You can check documentation at  [here](https://github.com/mahrtayyab/tweety)